@@ -31,6 +31,8 @@
 #include "object_fire2_device_status.h"
 #include "object_vcan4_device_status.h"
 #include "object_ics_device_status.h"
+#include "object_device_settings.h"
+#include "object_vcan4_settings.h"
 
 #define _DOC_ICS_MODULE \
     "Python C Code module for interfacing to the icsneo40 dynamic library. Code tries\n" \
@@ -55,11 +57,11 @@
     "\t...\n" \
     "\tneoVI FIRE 59886\n" \
     "\n" \
-    "It should be noted that :class:`"MODULE_NAME"."NEO_DEVICE_OBJECT_NAME"` is used a little bit differently than the C API.\n" \
-    ":class:`"MODULE_NAME"."NEO_DEVICE_OBJECT_NAME"` contains two extra members:\n" \
-    "\t:class:`"MODULE_NAME"."NEO_DEVICE_OBJECT_NAME".AutoHandleClose` and :class:`"MODULE_NAME"."NEO_DEVICE_OBJECT_NAME"._Handle`\n" \
+    "It should be noted that :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "` is used a little bit differently than the C API.\n" \
+    ":class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "` contains two extra members:\n" \
+    "\t:class:`" MODULE_NAME"." NEO_DEVICE_OBJECT_NAME ".AutoHandleClose` and :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "._Handle`\n" \
     "The handle normally returned from `icsneoOpenNeoDevice()` is stored inside _Handle and setting AutoHandleClose to True (Default)\n" \
-    "will automatically close the handle when the :class:`"MODULE_NAME"."NEO_DEVICE_OBJECT_NAME"` goes out of scope.\n" \
+    "will automatically close the handle when the :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "` goes out of scope.\n" \
     "\n" \
     "\n" \
     "Installation:\n" \
@@ -140,6 +142,8 @@ void initics(void)
     setup_fire2_device_status_object(module);
     setup_vcan4_device_status_object(module); // 803+
     setup_ics_device_status_object(module);
+    setup_device_settings_object(module);
+    setup_vcan4_settings_object(module); // 803+
 
 #if PY_MAJOR_VERSION >= 3
     return module;
